import { PropType, defineComponent, onMounted, reactive, ref } from 'vue';
import styles from './index.module.less';
import { NButton, NCascader, NInput, NSelect, NSpace } from 'naive-ui';
import { resourceTypeArray } from '/src/utils/searchArray';
import { useCatchStore } from '/src/store/modules/catchData';
import { useThrottleFn } from '@vueuse/core';

export default defineComponent({
  name: 'resource-search-group',
  emits: ['search'],
  props: {
    type: {
      type: String as PropType<
        'shareResources' | 'myResources' | 'myCollect' | 'relateResources'
      >,
      default: 'relateResources'
    }
  },
  setup(props, { emit }) {
    const catchStore = useCatchStore();
    const musics = ref([] as any);
    const forms = reactive({
      type: 'MUSIC', //
      name: '',
      // grade: null as any,
      bookVersionId: null as any,
      // musicSheetCategoriesId: null,
      musicalInstrumentId: ''
    });
    const resourceType = ref([] as any);

    const onSearch = () => {
      emit('search', forms);
    };

    const debouncedRequest = useThrottleFn(() => onSearch(), 500);

    // const formatParentId = (id: any, list: any, ids = [] as any) => {
    //   for (const item of list) {
    //     if (item.children && item.children.length > 0) {
    //       const cIds: any = formatParentId(id, item.children, [
    //         ...ids,
    //         item.id
    //       ]);
    //       if (cIds.includes(id)) {
    //         return cIds;
    //       }
    //     }
    //     if (item.id === id) {
    //       return [...ids, id];
    //     }
    //   }
    //   return ids;
    // };
    onMounted(async () => {
      // await catchStore.getMusicSheetCategory();
      await catchStore.getMusicTagTreeApi();
      // 获取教材分类列表
      await catchStore.getSubjects();

      resourceTypeArray.forEach((item: any) => {
        // if (props.type === 'myResources') {
        //   item.value !== 'MUSIC' && resourceType.value.push(item);
        // } else {
        resourceType.value.push(item);
        // }
      });
    });
    return () => (
      <>
        <div class={styles.searchGroup}>
          <NSpace size="small" class={styles.btnType}>
            {resourceType.value.map((item: any) => (
              <NButton
                type={forms.type === item.value ? 'primary' : 'default'}
                secondary={forms.type === item.value ? false : true}
                round
                size="small"
                focusable={false}
                onClick={() => {
                  forms.type = item.value;
                  debouncedRequest();
                }}>
                {item.label}
              </NButton>
            ))}
          </NSpace>

          <div class={styles.searchSelect}>
            <NCascader
              placeholder="全部乐器"
              options={[
                { name: '全部乐器', id: '' },
                ...catchStore.getSubjectList
              ]}
              clearable
              labelField="name"
              valueField="id"
              v-model:value={forms.musicalInstrumentId}
              onUpdate:value={() => {
                onSearch();
              }}
              checkStrategy="child"
              showPath={false}
              childrenField="instruments"
              expandTrigger="hover"
              filterable
            />
          </div>
          {forms.type === 'MUSIC' && props.type === 'shareResources' && (
            <div class={styles.searchSelect}>
              <NCascader
                placeholder="全部教材"
                options={[
                  { id: '', name: '全部教材' },
                  ...catchStore.getMusicTagTree
                ]}
                clearable
                style={{ width: '100%' }}
                childrenField="children"
                valueField="id"
                labelField="name"
                checkStrategy="child"
                expandTrigger="hover"
                showPath
                v-model:value={musics.value}
                onUpdate:value={(value: any) => {
                  // onSearch();
                  // const selectValue = formatParentId(value, [
                  //   { id: '', name: '全部教材' },
                  //   ...catchStore.getMusicTagTree
                  // ]);

                  forms.bookVersionId = value || '';
                  // forms.grade = selectValue[1] || '';
                  // forms.musicSheetCategoriesId = selectValue[2] || null;
                  onSearch();
                }}
              />
            </div>
          )}

          <NInput
            type="text"
            placeholder="请输入搜索关键词"
            clearable
            v-model:value={forms.name}
            class={styles.inputSearch}
            onKeyup={(e: KeyboardEvent) => {
              if (e.code === 'Enter') {
                debouncedRequest();
              }
            }}
            onClear={() => {
              forms.name = '';
              debouncedRequest();
            }}>
            {{
              prefix: () => (
                <span
                  class={'icon-search-input'}
                  onClick={() => debouncedRequest()}></span>
              )
            }}
          </NInput>
        </div>
      </>
    );
  }
});
